=== modified file 'bzrlib/benchmarks/bench_bundle.py'
--- bzrlib/benchmarks/bench_bundle.py	2006-08-19 02:17:16 +0000
+++ bzrlib/benchmarks/bench_bundle.py	2006-08-30 19:44:06 +0000
@@ -15,29 +15,25 @@
 
 """Tests for bzr bundle performance."""
 
+from cStringIO import StringIO
 import os
 import shutil
-from cStringIO import StringIO
 
+from bzrlib import bzrdir
 from bzrlib.add import smart_add
-from bzrlib import bzrdir
 from bzrlib.benchmarks import Benchmark
 from bzrlib.branch import Branch
 from bzrlib.bundle import read_bundle
+from bzrlib.bundle.apply_bundle import install_bundle
 from bzrlib.bundle.serializer import write_bundle
+from bzrlib.revision import NULL_REVISION
 from bzrlib.revisionspec import RevisionSpec
 from bzrlib.workingtree import WorkingTree
 
 
 class BundleBenchmark(Benchmark):
-    """The bundle tests should (also) be done at a lower level with
-    direct call to the bzrlib.
-    """
+    """Benchmarks for bzr bundle performance and bzr merge with a bundle."""
    
-    def make_kernel_like_tree_committed(self):
-        self.make_kernel_like_added_tree()
-        self.run_bzr('commit', '-m', 'initial import')
-
     def test_create_bundle_known_kernel_like_tree(self):
         """Create a bundle for a kernel sized tree with no ignored, unknowns,
         or added and one commit.
@@ -59,27 +55,37 @@
         """Create a bundle for a kernel sized tree with no ignored, unknowns,
         or added and one commit.
         """ 
-        self.make_kernel_like_tree_committed()
-        f = file('../bundle', 'wb')
+        tree = self.make_kernel_like_tree_committed('tree')
+
+        f = open('bundle', 'wb')
         try:
-            f.write(self.run_bzr('bundle', '--revision', '..-1')[0])
+            write_bundle(tree.branch.repository, tree.last_revision(),
+                         NULL_REVISION, f)
         finally:
             f.close()
-        self.run_bzr("init", "../branch_a")
-        os.chdir('../branch_a')
+
+        tree2 = self.make_branch_and_tree('branch_a')
+        os.chdir('branch_a')
         self.time(self.run_bzr, 'merge', '../bundle')
-
  
-class BundleLibraryLevelBenchmark(Benchmark):
+class BundleLibraryLevelWriteBenchmark(Benchmark):
+    """ Benchmarks for the write_bundle library function. """
 
     def _time_read_write(self):
+        print "timing"
         branch, relpath = Branch.open_containing("a")
         revision_history = branch.revision_history()
         bundle_text = StringIO()
+        print "starting write bundle"
         self.time(write_bundle, branch.repository, revision_history[-1],
-                  None, bundle_text)
+                  NULL_REVISION, bundle_text)
+        print "stopped writing bundle"
         bundle_text.seek(0)
-        self.time(read_bundle, bundle_text)
+        target_tree = self.make_branch_and_tree('b')
+        print "starting reading bundle"
+        bundle = self.time(read_bundle, bundle_text)
+        print "starting installing bundle"
+        self.time(install_bundle, target_tree.branch.repository, bundle)
 
     def test_few_files_small_tree_1_revision(self):
         os.mkdir("a")

=== modified file 'bzrlib/benchmarks/bench_info.py'
--- bzrlib/benchmarks/bench_info.py	2006-08-18 16:42:15 +0000
+++ bzrlib/benchmarks/bench_info.py	2006-08-30 19:44:06 +0000
@@ -33,4 +33,4 @@
         self.make_kernel_like_committed_tree()
         self.time(self.run_bzr, 'info')
 
- 
+     

=== modified file 'bzrlib/benchmarks/tree_creator/many_commit.py'
--- bzrlib/benchmarks/tree_creator/many_commit.py	2006-08-19 02:17:16 +0000
+++ bzrlib/benchmarks/tree_creator/many_commit.py	2006-08-30 19:44:06 +0000
@@ -27,8 +27,10 @@
     """Create an tree many files and many commits."""
 
     def __init__(self, test, link_bzr=False, num_files=10, num_commits=10):
+        tree_name = 'many_files_many_commit_tree_%d_%d' % (
+            num_files, num_commits)
         super(ManyCommitTreeCreator, self).__init__(test,
-            tree_name='many_files_many_commit_tree',
+            tree_name=tree_name,
             link_bzr=link_bzr,
             link_working=False,
             hot_cache=True)
@@ -39,7 +41,7 @@
     def _create_tree(self, root, in_cache=False):
         num_files = self.num_files
         num_commits = self.num_commits
-        files = ["%s/%s" % (root, i) for i in range(num_files)]
+        files = ["%s/%s" % (root, fn) for fn in self.files]
         for fn in files:
             f = open(fn, "wb")
             try:
@@ -47,7 +49,7 @@
             finally:
                 f.close()
         tree = bzrdir.BzrDir.create_standalone_workingtree(root)
-        tree.add([str(i) for i in range(num_files)])
+        tree.add(self.files)
         tree.lock_write()
         try:
             tree.commit('initial commit')
@@ -62,6 +64,5 @@
                 tree.commit("changing file %s" % fn)
         finally:
             tree.unlock()
-        self.files = ["%s" % (i, ) for i in range(num_files)]
         return tree
 

